Index: Source/core/workers/WorkerGlobalScopeProxy.h |
diff --git a/Source/core/workers/WorkerContextProxy.h b/Source/core/workers/WorkerGlobalScopeProxy.h |
similarity index 76% |
rename from Source/core/workers/WorkerContextProxy.h |
rename to Source/core/workers/WorkerGlobalScopeProxy.h |
index 6b1858e34d1a21d24de8f67bdff71057746390ea..67ffca3e1d10b655dfb2cf5b8626cdb1092e092b 100644 |
--- a/Source/core/workers/WorkerContextProxy.h |
+++ b/Source/core/workers/WorkerGlobalScopeProxy.h |
@@ -28,36 +28,36 @@ |
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
*/ |
-#ifndef WorkerContextProxy_h |
-#define WorkerContextProxy_h |
+#ifndef WorkerGlobalScopeProxy_h |
+#define WorkerGlobalScopeProxy_h |
#include "core/dom/MessagePort.h" |
#include "core/workers/WorkerThread.h" |
-#include <wtf/Forward.h> |
-#include <wtf/PassOwnPtr.h> |
+#include "wtf/Forward.h" |
+#include "wtf/PassOwnPtr.h" |
namespace WebCore { |
class KURL; |
class Worker; |
- // A proxy to talk to the worker context. |
- class WorkerContextProxy { |
+ // A proxy to talk to the worker global scope. |
+ class WorkerGlobalScopeProxy { |
public: |
- typedef WorkerContextProxy* CreateDelegate(Worker*); |
+ typedef WorkerGlobalScopeProxy* CreateDelegate(Worker*); |
// FIXME: Instead of delegating through a static factory function we |
// should probably go through some client interface like ChromeClient. |
- static WorkerContextProxy* create(Worker* worker) { return s_createDelegate(worker); } |
+ static WorkerGlobalScopeProxy* create(Worker* worker) { return s_createDelegate(worker); } |
static void setCreateDelegate(CreateDelegate* delegate) { s_createDelegate = delegate; } |
- virtual ~WorkerContextProxy() {} |
+ virtual ~WorkerGlobalScopeProxy() { } |
- virtual void startWorkerContext(const KURL& scriptURL, const String& userAgent, const String& sourceCode, WorkerThreadStartMode) = 0; |
+ virtual void startWorkerGlobalScope(const KURL& scriptURL, const String& userAgent, const String& sourceCode, WorkerThreadStartMode) = 0; |
- virtual void terminateWorkerContext() = 0; |
+ virtual void terminateWorkerGlobalScope() = 0; |
- virtual void postMessageToWorkerContext(PassRefPtr<SerializedScriptValue>, PassOwnPtr<MessagePortChannelArray>) = 0; |
+ virtual void postMessageToWorkerGlobalScope(PassRefPtr<SerializedScriptValue>, PassOwnPtr<MessagePortChannelArray>) = 0; |
virtual bool hasPendingActivity() const = 0; |
@@ -78,4 +78,4 @@ namespace WebCore { |
} // namespace WebCore |
-#endif // WorkerContextProxy_h |
+#endif // WorkerGlobalScopeProxy_h |